@@ -30,7 +30,7 @@ from s3_file_field import S3FileField
 from .. import tasks
 from .collection import Collection
 from .fileset import FileSet
-from .mixins import PermissionPathMixin, TaskEventMixin
+from .mixins import TaskEventMixin
 
 logger = logging.getLogger(__name__)
 
@@ -40,7 +40,7 @@ class FileSourceType(models.IntegerChoices):
     URL = 2, 'URL'
 
 
-class ChecksumFile(TimeStampedModel, TaskEventMixin, PermissionPathMixin):
+class ChecksumFile(TimeStampedModel, TaskEventMixin):
     """The main class for user-uploaded files.
 
     This has support for manually uploading files or specifying a URL to a file
@@ -75,7 +75,6 @@ class ChecksumFile(TimeStampedModel, TaskEventMixin, PermissionPathMixin):
     url = models.TextField(null=True, blank=True)
 
     task_funcs = (tasks.task_checksum_file_post_save,)
-    permissions_paths = [('collection', Collection)]
 
     class Meta:
         constraints = [
@@ -103,6 +102,14 @@ class ChecksumFile(TimeStampedModel, TaskEventMixin, PermissionPathMixin):
     def basename(self):
         return os.path.basename(self.name)
 
+    @property
+    def size(self):
+        # Ensure safe check of self.file
+        try:
+            return self.file.size
+        except ValueError:
+            return None
+
     def get_checksum(self):
         """Compute a new checksum without saving it."""
         if self.type == FileSourceType.FILE_FIELD:
@@ -187,7 +194,7 @@ class ChecksumFile(TimeStampedModel, TaskEventMixin, PermissionPathMixin):
 
         This will handle locking to prevent multiple processes/threads
         from trying to download the file at the same time -- only one thread
-        or process will perfrom the download and the rest will yield its
+        or process will perform the download and the rest will yield its
         result.
 
         """
@@ -202,13 +209,13 @@ class ChecksumFile(TimeStampedModel, TaskEventMixin, PermissionPathMixin):
         with lock:  # TODO: handle timeouts in condition
             if dest_path.exists() and dest_path.stat().st_size > 0:
                 # File already exists (is cached)
-                logger.info(f'Found cached file ({self.pk}) at: {dest_path}')
+                logger.debug(f'Found cached file ({self.pk}) at: {dest_path}')
                 # Touch the file so that it moves to the top of the priority list
                 # when cleaning.
                 dest_path.touch()
                 return dest_path
             else:
-                logger.info(f'Downloading file ({self.pk}) to: {dest_path}')
+                logger.debug(f'Downloading file ({self.pk}) to: {dest_path}')
                 # If downloading to the cache, clean to achieve available free space
                 if get_cache_dir() in dest_path.parents:
                     clean_file_cache()
@@ -228,7 +235,8 @@ class ChecksumFile(TimeStampedModel, TaskEventMixin, PermissionPathMixin):
         """
         if self.file_set is None:
             # If no file_set, place in the main cache directory
-            directory = get_cache_dir()
+            directory = get_cache_dir() / f'f-{self.pk}'
+            directory.mkdir(parents=True, exist_ok=True)
         else:
             directory = self.file_set.get_cache_path()
         return directory / f'{self.name}'
@@ -265,16 +273,16 @@ class ChecksumFile(TimeStampedModel, TaskEventMixin, PermissionPathMixin):
             return
         # Fallback to loading entire file locally - this uses `get_temp_path`
         logger.debug('`yield_local_path` falling back to downloading entire file to local storage.')
+        path = self.get_cache_path()
         if yield_file_set and self.file_set:
             # NOTE: This is messy and should be improved but it ensures the directory remains locked
             with self.file_set.yield_all_to_local_path() as _:
-                yield self.get_cache_path()
+                yield path
             return
         # Not in file_set. Download to cache dir
-        path = self.download_to_local_path()
-        # provide a lock on this file while yielding
-        lock = get_file_lock(path)
-        with lock:
+        from .utils import yield_checksumfiles
+
+        with yield_checksumfiles([self], path.parent):
             yield path
 
     def get_url(self, internal: bool = False):
